@@ -1,20 +1,13 @@
 package Test::Spec::RMock::AtLeastConstraint;
 
-use Moose;
-use namespace::autoclean;
-
-has _bound => (is => 'ro');
-
-
-around BUILDARGS => sub {
-    my ($orig, $class, $bound) = @_;
-    my $self = $orig->($class, _bound => $bound);
-};
-
+sub new {
+    my ($class, $bound) = @_;
+    bless { _bound => $bound }, $class;
+}
 
 sub call {
     my ($self, $times_called) = @_;
-    $times_called >= $self->_bound;
+    $times_called >= $self->{_bound};
 }
 
 1;
@@ -29,7 +22,7 @@ Test::Spec::RMock::AtLeastConstraint
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 AUTHOR
 
